import React from 'react';
import { ThemeProvider } from '@mui/material/styles';

import {
    Menu, MenuItem, Container, Avatar, Badge, IconButton, Divider,
    Typography, List, Toolbar, Box, CssBaseline, useMediaQuery as Size,
} from '@mui/material'

import {
    Mail as MailIcon, Notifications as NotificationsIcon, Fullscreen as FullscreenIcon,
    Menu as MenuIcon,
} from '@mui/icons-material'

import useAuth from '../Auth/useAuth';
import Logo from '../Images/logo.png';
import ProfilePicture from '../Images/man.png';

import { Outlet, useNavigate } from "react-router-dom";
import { MenuMovil } from '../Components/Navigation/MenuMovil';
import Footer from "../Components/Footer";

import { mdTheme } from '../Utils/theme'
import { Drawer, AppBar } from "../Components/Navigation/AppBar"
import { MainListItems, SecondaryListItems } from '../Components/Navigation/listItems';

function DashboardContent() {

    const [open, setOpen] = React.useState(false);

    const isMovil = Size('(min-width:770px)');
    const auth = useAuth();
    const navigate = useNavigate()

    const toggleDrawer = () => setOpen(!open);
    const [anchorEl, setAnchorEl] = React.useState(null);
    const open_profile = Boolean(anchorEl);
    const handleClick = (event) => setAnchorEl(event.currentTarget);
    const handleClose = () => setAnchorEl(null)

    const [anchorElMovil, setAnchorElMov] = React.useState(false);
    const MenuResponsive = () => {
        console.log(anchorElMovil)
        setAnchorElMov(!anchorElMovil);
    }

    const CerrarSession = () => {
        console.log('cerrando session')
        auth.logout();
        navigate('/')
    }

    return (
        <ThemeProvider theme={mdTheme}>

            <MenuMovil
                anchor={anchorElMovil}
                control={setAnchorElMov} />

            <Box sx={{ display: 'flex' }}>
                <CssBaseline />
                <AppBar style={{ backgroundColor: '#fff', boxShadow: 'None' }} position="absolute" open={!isMovil ? open : false}>
                    <Toolbar sx={{ pr: '24px', borderBottom: "1px solid #ec5e69" }} >

                        {/* boton para activar navegacion */}
                        <IconButton
                            edge="start"
                            color="inherit"
                            aria-label="open drawer"
                            onClick={!isMovil ? MenuResponsive : toggleDrawer}
                            sx={{ marginRight: '36px', ...(!isMovil && open && { display: 'none' }), }} >
                            <MenuIcon style={{
                                background: '#ec5e69',
                                fontSize: "40",
                                color: "#fff"
                            }} />
                        </IconButton>

                        <Typography component="h1" variant="h6" color="inherit" noWrap sx={{ flexGrow: 1 }} >
                            {
                                !isMovil && open ? (
                                    <React.Fragment>

                                        <IconButton onClick={toggleDrawer}>
                                            <MenuIcon />
                                        </IconButton>

                                        <IconButton onClick={(event) => event.target.requestFullscreen()}>
                                            <FullscreenIcon style={{ paddinLeft: 15 }} />
                                        </IconButton>
                                    </React.Fragment>
                                ) : undefined
                            }
                        </Typography>


                        <Box sx={{ display: { xs: 'none', md: 'flex' } }}>
                            <IconButton size="large" aria-label="show 4 new mails" color="inherit">
                                <Badge badgeContent={4} color="error">
                                    <MailIcon style={{ color: '#212529' }} />
                                </Badge>
                            </IconButton>
                            <IconButton
                                size="large"
                                aria-label="show 17 new notifications"
                                color="inherit">
                                <Badge badgeContent={17} color="error">
                                    <NotificationsIcon style={{ color: '#212529' }} />
                                </Badge>
                            </IconButton>


                            <IconButton
                                size="small"
                                edge="end"
                                aria-label="account of current user"
                                aria-haspopup="true"
                                aria-expanded={open_profile ? 'true' : undefined}
                                onClick={handleClick}
                                color="inherit" >
                                <Avatar alt="profile picture" src={ProfilePicture} />
                            </IconButton>
                            <Menu
                                id="basic-menu"
                                anchorEl={anchorEl}
                                open={open_profile}
                                onClose={handleClose}
                                MenuListProps={{ 'aria-labelledby': 'basic-button', }}>
                                <MenuItem onClick={() => navigate('dashboard/perfil')}>Mi Cuenta</MenuItem>
                                <MenuItem onClick={() => console.log('dashboard/perfil')}>Configuraciones</MenuItem>
                                <MenuItem onClick={CerrarSession}>Cerrar Sesión</MenuItem>
                            </Menu>
                        </Box>
                    </Toolbar>
                </AppBar>
                <Drawer variant="permanent" open={open}>
                    <Toolbar
                        sx={{
                            display: 'flex',
                            alignItems: 'center',
                            justifyContent: 'flex-start',
                            px: [1]
                        }} >
                        <div style={{ flat: 'righ' }} className="sidebar-header">
                            <div className="width_img">
                                <img src={Logo} alt="pruebas psicometricas" />
                            </div>
                        </div>
                    </Toolbar>
                    <Divider />
                    <List>
                        <MainListItems AppBarVisible={open} setAppBarVisible={setOpen} />
                    </List>
                    <Divider />
                    <List>
                        {SecondaryListItems}
                    </List>
                </Drawer>
                <Container maxWidth="lg" sx={{ mt: 2, mb: 2 }}>
                    <Outlet />
                    <Footer />
                </Container>
            </Box>
        </ThemeProvider>
    );
}

export function Dashboard() {
    return <DashboardContent />;
}

